clear all;

% Call "baseline.m" to subtract baseline run off of each data point from w.t. tests
%
% Outputs are delta(Cx) values in variables:
%    TE[L,R][1-12]_alfa[4,6,8] in format:
%      df=-15 [ CL   CD   Cm   Cl   Cn   CY ]
%      df=-10 | CL   CD   Cm   Cl   Cn   CY |
%      df=-5  | CL   CD   Cm   Cl   Cn   CY |
%      df=0   | 0    0    0    0    0    0  |
%      df=5   | CL   CD   Cm   Cl   Cn   CY |
%      df=10  | CL   CD   Cm   Cl   Cn   CY |
%      df=15  [ CL   CD   Cm   Cl   Cn   CY ]
% ERROR exists on TER1_alfa6 -- w.t. tests were run at Alpha=0
baseline

% "rearrange.m" changes matrices from Effector-based to Coefficient-based
%
% Outputs are Cx values in variable:
%    TE[R.L]_C[x]_alfa[4,6,8] in format:
%      df=-15 [ CL(eff1)  CL(eff2) .. CL(eff12) ]
%      df=-10 | CL(eff1)  CL(eff2) .. CL(eff12) |
%      df=-5  | CL(eff1)  CL(eff2) .. CL(eff12) |
%      df=5   | CL(eff1)  CL(eff2) .. CL(eff12) |
%      df=10  | CL(eff1)  CL(eff2) .. CL(eff12) |
%      df=15  [ CL(eff1)  CL(eff2) .. CL(eff12) ]
%
% Rolling Moment coefficient renamed to Cr
rearrange

% "CDrecalc.m" redefines CD based off of Cn data -- back out the drag by
% CD=(b/l)*Cn
% where l=moment arm of effector
% Also remove the 0 data point from drag and yaw data
CDrecalc


% "slopes.m" uses the matrices formed in "rearrange.m" and calculates a 1st or 2nd
% degree polynomial fit for each 
%
% For CL, Cm, and Cr results are in form:
%   TEx_Cx_slopes:
%            alfa4 [ TEx1  TEx2 .. TEx12 ]
%            alfa6 | TEx1  TEx2 .. TEx12 |
%            alfa8 [ TEx1  TEx2 .. TEx12 ]
%   TEx_Cx_intercepts:
%            alfa4 [ TEx1  TEx2 .. TEx12 ]
%            alfa6 | TEx1  TEx2 .. TEx12 |
%            alfa8 [ TEx1  TEx2 .. TEx12 ]
slopes

% alfaslopes.m
% take TEx_Cx_alfa[4,6,8], create matrix of slopes of Cx vs Alfa
% Therefore, for any desired input alpha, we can use the following equation:
%    (dCx/ddf)/da*alfa*df = Cx
alfaslopes

% "dragcalcs.m" and "yawcalcs.m" solve 2nd order polynomials for drag and yaw values
dragcalcs
yawcalcs

% "inputs.m" allows user to input the alpha, deflection shape and angle, and symmetry of effector array.
inputs

% full prediction through a range of deflection angles
deflection=[-15 -12 -9 -6 -3 0 3 6 9 12 15]';
for k=1:11
% "prediction.m" uses the matrices formed in "slopes.m" and deflection vectors to calculate
% Cl,Cm,Cr distribution across wing for the given alpha, deflection shape, and deflection angle.
% These distributions are integrated along the span to produce total coefficients CL, Cm, and Cr
% 
% Calculations are simple element-multiplication of deflection angle and coefficient slope.
    prediction

    % "gaussinterp.m" 
    gaussinterp

end
alfa
shape
FinalSoln=[CL' Cm' Cr' CD' Cn' CDgauss']