% "prediction.m" uses the matrices formed in "slopes.m" and deflection vectors to calculate
% Cl,Cm,Cr distribution across wing for the given alpha, deflection shape, and deflection angle.
% These distributions are integrated along the span to produce total coefficients CL, Cm, and Cr
% 
% Calculations are simple element-multiplication of deflection angle and coefficient slope.





% Effector center y-location measured from inboard to outboard, starting at
% 
effectorlocation=[0 1 2 3 4 5 6 7 8 9 10 11]*3/2+3/4;

if shape==1
    dfr=deflection(k)*[1 1 1 1 1 1 1 1 1 1 1 1]*directionright;
    dfl=deflection(k)*[1 1 1 1 1 1 1 1 1 1 1 1]*directionleft;
elseif shape==2
    % Deflections listed inboard to outboard
    dfr=deflection(k)/18*effectorlocation*directionright;
    dfl=deflection(k)/18*effectorlocation*directionleft;
elseif shape==3
    % Deflections listed inboard to outboard
    dfr=deflection(k)*sin(pi/18*effectorlocation)*directionright;
    dfl=deflection(k)*sin(pi/18*effectorlocation)*directionleft;
elseif shape==4
    dfr=deflection(k)*sin(pi/9*effectorlocation)*directionright;
    dfl=deflection(k)*sin(pi/9*effectorlocation)*directionleft;
elseif shape==5
    dfr=deflection(k)*sin(pi/6*effectorlocation)*directionright;
    dfl=deflection(k)*sin(pi/6*effectorlocation)*directionleft;
elseif shape==6
    dfr=deflection(k)*[1 -1 1 -1 1 -1 1 -1 1 -1 1 -1]*directionright;
    dfl=deflection(k)*[1 -1 1 -1 1 -1 1 -1 1 -1 1 -1]*directionleft;
end

if alfa==4
    m=1;
    for i=1:12
        Cddistl(i) = A_L4(i,1).*dfl(i)^2 + A_L4(i,2).*dfl(i); % + A_L4(:,3)
        Cddistr(i) = A_R4(i,1).*dfr(i)^2 + A_R4(i,2).*dfr(i); % + A_R4(:,3)  
        
        Cndistl(i) = B_L4(i,1).*dfl(i)^2 + B_L4(i,2).*dfl(i); % + B_L4(:,3)
        Cndistr(i) = B_R4(i,1).*dfr(i)^2 + B_R4(i,2).*dfr(i); % + B_R4(:,3)  
    end
elseif alfa==6
    for i=1:12
        Cddistl(i) = A_L6(i,1).*dfl(i)^2 + A_L6(i,2).*dfl(i); % + A_L6(:,3)
        Cddistr(i) = A_R6(i,1).*dfr(i)^2 + A_R6(i,2).*dfr(i); % + A_R6(:,3) 

        Cndistl(i) = B_L6(i,1).*dfl(i)^2 + B_L6(i,2).*dfl(i); % + B_L6(:,3)
        Cndistr(i) = B_R6(i,1).*dfr(i)^2 + B_R6(i,2).*dfr(i); % + B_R6(:,3) 
    end
    m=2;
elseif alfa==8
    for i=1:12
        Cddistl(i) = A_L8(i,1).*dfl(i)^2 + A_L8(i,2).*dfl(i); % + A_L8(:,3)
        Cddistr(i) = A_R8(i,1).*dfr(i)^2 + A_R8(i,2).*dfr(i); % + A_R8(:,3) 

        Cndistl(i) = B_L8(i,1).*dfl(i)^2 + B_L8(i,2).*dfl(i); % + B_L8(:,3)
        Cndistr(i) = B_R8(i,1).*dfr(i)^2 + B_R8(i,2).*dfr(i); % + B_R8(:,3) 
    end
    m=3;
end






% Calculate distribution of Cl, Cm, Cr across 24 effectors by performing element multiplication of 
% effectiveness slope vector with deflection vector
%Clrdist = dfr.*TER_CL_slopes(m,:);
%Clldist = dfl.*TEL_CL_slopes(m,:);
%Cmrdist = dfr.*TER_Cm_slopes(m,:);
%Cmldist = dfl.*TEL_Cm_slopes(m,:);
%Crrdist = -1*dfr.*TER_Cr_slopes(m,:);
%Crldist = -1*dfl.*TEL_Cr_slopes(m,:);


Cldistr = dfr.*TER_CL_alfaslope*alfa;
Cldistl = dfl.*TEL_CL_alfaslope*alfa;
Cmdistr = dfr.*TER_Cm_alfaslope*alfa;
Cmdistl = dfl.*TEL_Cm_alfaslope*alfa;
Crdistr = -1*dfr.*TER_Cr_alfaslope*alfa;
Crdistl = -1*dfl.*TEL_Cr_alfaslope*alfa;


CL(k) = sum(Cldistl) + sum(Cldistr);
Cm(k) = sum(Cmdistl) + sum(Cmdistr);
Cr(k) = sum(Crdistl) + sum(Crdistr);
CD(k) = sum(Cddistl) + sum(Cddistr);
Cn(k) = sum(Cndistl) + sum(Cndistr);