% "slopes.m" uses the matrices formed in "rearrange.m" and calculates a 1st or 2nd
% degree polynomial fit for each 
%
% Results are in form:
%   TEx_Cx_slopes:
%            alfa4 [ TEx1(dCx/ddf)  TEx2 .. TEx12 ]
%            alfa6 | TEx1(dCx/ddf)  TEx2 .. TEx12 |
%            alfa8 [ TEx1(dCx/ddf)  TEx2 .. TEx12 ]
%   TEx_Cx_intercepts:
%            alfa4 [ TEx1  TEx2 .. TEx12 ]
%            alfa6 | TEx1  TEx2 .. TEx12 |
%            alfa8 [ TEx1  TEx2 .. TEx12 ]


% Use matrix TEL_CL_alfa4, TEL_CL_alfa6, TEL_CL_alfa8 to create TEL_CL_slopes


defl = [15 10 5 0 -5 -10 -15]';


for i=1:12
    % CL Lift coefficient for Left Wing
    p = polyfit(defl,TEL_CL_alfa4(:,i),1);
    TEL_CL_slopes(1,i) = p(1);
    TEL_CL_intercepts(1,i) = p(2);
    p = polyfit(defl,TEL_CL_alfa6(:,i),1);
    TEL_CL_slopes(2,i) = p(1);
    TEL_CL_intercepts(2,i) = p(2);
    p = polyfit(defl,TEL_CL_alfa8(:,i),1);
    TEL_CL_slopes(3,i) = p(1);
    TEL_CL_intercepts(3,i) = p(2);
    % CL Lift coefficient for Right Wing
    p = polyfit(defl,TER_CL_alfa4(:,i),1);
    TER_CL_slopes(1,i) = p(1);
    TER_CL_intercepts(1,i) = p(2);
    p = polyfit(defl,TER_CL_alfa6(:,i),1);
    TER_CL_slopes(2,i) = p(1);
    TER_CL_intercepts(2,i) = p(2);
    p = polyfit(defl,TER_CL_alfa8(:,i),1);
    TER_CL_slopes(3,i) = p(1);
    TER_CL_intercepts(3,i) = p(2);
    
    % Cm Pitching Moment Coefficient for Left Wing
    p = polyfit(defl,TEL_Cm_alfa4(:,i),1);
    TEL_Cm_slopes(1,i) = p(1);
    TEL_Cm_intercepts(1,i) = p(2);
    p = polyfit(defl,TEL_Cm_alfa6(:,i),1);
    TEL_Cm_slopes(2,i) = p(1);
    TEL_Cm_intercepts(2,i) = p(2);
    p = polyfit(defl,TEL_Cm_alfa8(:,i),1);
    TEL_Cm_slopes(3,i) = p(1);
    TEL_Cm_intercepts(3,i) = p(2);
    % Cm Pitching Moment Coefficient for Right Wing
    p = polyfit(defl,TER_Cm_alfa4(:,i),1);
    TER_Cm_slopes(1,i) = p(1);
    TER_Cm_intercepts(1,i) = p(2);
    p = polyfit(defl,TER_Cm_alfa6(:,i),1);
    TER_Cm_slopes(2,i) = p(1);
    TER_Cm_intercepts(2,i) = p(2);
    p = polyfit(defl,TER_Cm_alfa8(:,i),1);
    TER_Cm_slopes(3,i) = p(1);
    TER_Cm_intercepts(3,i) = p(2);
    
    % Cr Rolling Moment Coefficient for Left Wing
    p = polyfit(defl,TEL_Cr_alfa4(:,i),1);
    TEL_Cr_slopes(1,i) = p(1);
    TEL_Cr_intercepts(1,i) = p(2);
    p = polyfit(defl,TEL_Cr_alfa6(:,i),1);
    TEL_Cr_slopes(2,i) = p(1);
    TEL_Cr_intercepts(2,i) = p(2);
    p = polyfit(defl,TEL_Cr_alfa8(:,i),1);
    TEL_Cr_slopes(3,i) = p(1);
    TEL_Cr_intercepts(3,i) = p(2);
    % Cr Rolling Moment Coefficient for Right Wing
    p = polyfit(defl,TER_Cr_alfa4(:,i),1);
    TER_Cr_slopes(1,i) = p(1);
    TER_Cr_intercepts(1,i) = p(2);
    p = polyfit(defl,TER_Cr_alfa6(:,i),1);
    TER_Cr_slopes(2,i) = p(1);
    TER_Cr_intercepts(2,i) = p(2);
    p = polyfit(defl,TER_Cr_alfa8(:,i),1);
    TER_Cr_slopes(3,i) = p(1);
    TER_Cr_intercepts(3,i) = p(2);
end

clear p;
clear TEL_CL_alfa4 TEL_CL_alfa6 TEL_CL_alfa8 TER_CL_alfa4 TER_CL_alfa6 TER_CL_alfa8;
clear TEL_Cm_alfa4 TEL_Cm_alfa6 TEL_Cm_alfa8 TER_Cm_alfa4 TER_Cm_alfa6 TER_Cm_alfa8;
clear TEL_Cr_alfa4 TEL_Cr_alfa6 TEL_Cr_alfa8 TER_Cr_alfa4 TER_Cr_alfa6 TER_Cr_alfa8;